==> vod-common-1.0.0-sources.jar: com/valor/vod/common/tools/type/StringTools.java <==
package com.valor.vod.common.tools.type;

import com.google.common.base.Joiner;
import com.google.common.base.Splitter;
import com.google.common.base.Strings;
import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.List;
import java.util.Map;

/**
 * Created by Frank.Huang on 2016/5/14.
 */
public class StringTools {
    private static final Logger logger = LoggerFactory.getLogger(StringTools.class);

    public static Map<String, String> parseAsMap(String str, String entrySeparator, String keyValueSeparator) {
        Map<String, String> valueMap = Maps.newHashMap();
        if (!Strings.isNullOrEmpty(str)) {
            try {
                valueMap = Splitter.on(entrySeparator)
                    .omitEmptyStrings()
                    .trimResults()
                    .withKeyValueSeparator(keyValueSeparator)
                    .split(str);
            } catch (Exception e) {
                logger.error("STR2MAP error:[{}-({})-({})]", str, entrySeparator, keyValueSeparator);
            }
        }

        return valueMap;
    }

    public static List<String> parseAsList(String str, String entrySeparator) {
        if (!Strings.isNullOrEmpty(str)) {
            try {
                return Splitter.on(entrySeparator).omitEmptyStrings().trimResults().splitToList(str);
            } catch (Exception e) {
                logger.error("String To List error:[{}-{}]", str, entrySeparator);
            }
        }

        return Lists.newArrayList();
    }

    public static int toInt(String str) {
        if (Strings.isNullOrEmpty(str)) {
            return 0;
        }

        try {
            return Integer.valueOf(str);
        } catch (NumberFormatException e) {
            logger.warn("String[{}] cast to int failed:{}", str, e);
            return 0;
        }
    }


    public static String firstToUpperCase(String str) {
        if (Strings.isNullOrEmpty(str)) {
            return str;
        }

        String[] strs = str.split(" ");
        List<String> strList = Lists.newArrayList();
        for (String s : strs) {
            if (Strings.isNullOrEmpty(s)) {
                strList.add(s);
            } else {
                strList.add(s.substring(0, 1).toUpperCase() + s.substring(1));
            }
        }

        return Joiner.on(" ").join(strList);
    }


    public static boolean eq(String s1, String s2) {
        if (s1 == null && s2 == null) {
            return true;
        }

        if (s1 == null && s2 != null) {
            return false;
        }

        if (s1 != null && s2 == null) {
            return false;
        }

        return (s1.compareTo(s2) == 0);
    }

    public static String addZeroForNum(String str, int strLength) {
        int strLen = str.length();
        if (strLen < strLength) {
            while (strLen < strLength) {
                StringBuffer sb = new StringBuffer();
                sb.append("0").append(str);// 左补0
                // sb.append(str).append("0");//右补0
                str = sb.toString();
                strLen = str.length();
            }
        }

        return str;
    }


}

==> vod-common-1.0.2-sources.jar: com/valor/vod/common/tools/type/StringTools.java <==
package com.valor.vod.common.tools.type;

import com.google.common.base.Joiner;
import com.google.common.base.Splitter;
import com.google.common.base.Strings;
import com.google.common.collect.Lists;
import com.google.common.collect.Maps;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.List;
import java.util.Map;

/** Created by Frank.Huang on 2016/5/14. */
public class StringTools {
    private static final Logger logger = LoggerFactory.getLogger(StringTools.class);

    public static Map<String, String> parseAsMap(
            String str, String entrySeparator, String keyValueSeparator) {
        Map<String, String> valueMap = Maps.newHashMap();
        if (!Strings.isNullOrEmpty(str)) {
            try {
                valueMap =
                        Splitter.on(entrySeparator)
                                .omitEmptyStrings()
                                .trimResults()
                                .withKeyValueSeparator(keyValueSeparator)
                                .split(str);
            } catch (Exception e) {
                logger.error(
                        "STR2MAP error:[{}-({})-({})]", str, entrySeparator, keyValueSeparator);
            }
        }

        return valueMap;
    }

    public static List<String> parseAsList(String str, String entrySeparator) {
        if (!Strings.isNullOrEmpty(str)) {
            try {
                return Splitter.on(entrySeparator)
                        .omitEmptyStrings()
                        .trimResults()
                        .splitToList(str);
            } catch (Exception e) {
                logger.error("String To List error:[{}-{}]", str, entrySeparator);
            }
        }

        return Lists.newArrayList();
    }

    public static int toInt(String str) {
        if (Strings.isNullOrEmpty(str)) {
            return 0;
        }

        try {
            return Integer.valueOf(str);
        } catch (NumberFormatException e) {
            logger.warn("String[{}] cast to int failed:{}", str, e);
            return 0;
        }
    }

    public static String firstToUpperCase(String str) {
        if (Strings.isNullOrEmpty(str)) {
            return str;
        }

        String[] strs = str.split(" ");
        List<String> strList = Lists.newArrayList();
        for (String s : strs) {
            if (Strings.isNullOrEmpty(s)) {
                strList.add(s);
            } else {
                strList.add(s.substring(0, 1).toUpperCase() + s.substring(1));
            }
        }

        return Joiner.on(" ").join(strList);
    }

    public static boolean eq(String s1, String s2) {
        if (s1 == null && s2 == null) {
            return true;
        }

        if (s1 == null && s2 != null) {
            return false;
        }

        if (s1 != null && s2 == null) {
            return false;
        }

        return (s1.compareTo(s2) == 0);
    }

    public static String addZeroForNum(String str, int strLength) {
        int strLen = str.length();
        if (strLen < strLength) {
            while (strLen < strLength) {
                StringBuffer sb = new StringBuffer();
                // 左补0
                sb.append("0").append(str);
                // sb.append(str).append("0");//右补0
                str = sb.toString();
                strLen = str.length();
            }
        }

        return str;
    }
}
